import os
import time
from datetime import datetime
import base64
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.image import MIMEImage
from email.utils import formataddr
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from PIL import Image


def send_email(email_sender, email_recipient, email_cc, subject, body, image_path):
    msg = MIMEMultipart()
    smtp_server = 'smtp.office365.com'
    port = 587
    msg['From'] = formataddr([email_sender[0].split('@')[0], email_sender[0]])
    msg['To'] = ', '.join(email_recipient)
    msg['Cc'] = ', '.join(email_cc)
    msg['Subject'] = subject

    html_body = f'''
        <html>
            <body>
                <p>This email is generated by {os.popen('whoami').read().strip()} on {time}</p>
                <p>========================================================================</p>
                <p>{body}</p>
                <img src="cid:image1">
            </body>
        </html>
        '''
    msg.attach(MIMEText(html_body, 'html'))

    with open(image_path, 'rb') as img:
        mime_image = MIMEImage(img.read())
        mime_image.add_header('Content-ID', '<image1>')
        msg.attach(mime_image)

    try:
        with smtplib.SMTP(smtp_server, port) as server:
            server.ehlo()
            server.starttls()
            server.ehlo()
            print("try to login SMTP Server...")
            server.login(email_sender[0], email_sender[1])
            print("login sucessfully...")
            server.send_message(msg)
            print("email send sucessfully")
    except smtplib.SMTPAuthenticationError as auth_error:
        print(f"Failed authentication: {auth_error}")
    except Exception as e:
        print(f"Failed to send mail: {e}")
